smartsheet.models.enums package — Smartsheet Python SDK 2.86.1.dev21+gb23b642 documentation

# smartsheet.models.enums package

## Submodules

## smartsheet.models.enums.access_level module

class `smartsheet.models.enums.access_level.` `AccessLevel`(value)

  Bases: `enum.Enum`

  An enumeration.

  `ADMIN` = 4
  `EDITOR` = 2
  `EDITOR_SHARE` = 3
  `OWNER` = 5
  `VIEWER` = 1

## smartsheet.models.enums.attachment_parent_type module

class `smartsheet.models.enums.attachment_parent_type.` `AttachmentParentType`(value)

  Bases: `enum.Enum`

  An enumeration.

  `COMMENT` = 3
  `ROW` = 2
  `SHEET` = 1

## smartsheet.models.enums.attachment_sub_type module

class `smartsheet.models.enums.attachment_sub_type.` `AttachmentSubType`(value)

  Bases: `enum.Enum`

  An enumeration.

  `DOCUMENT` = 1
  `DRAWING` = 5
  `FOLDER` = 6
  `PDF` = 4
  `PRESENTATION` = 3
  `SPREADSHEET` = 2

## smartsheet.models.enums.attachment_type module

class `smartsheet.models.enums.attachment_type.` `AttachmentType`(value)

  Bases: `enum.Enum`

  An enumeration.

  `BOX_COM` = 4
  `DROPBOX` = 5
  `EGNYTE` = 7
  `EVERNOTE` = 6
  `FILE` = 1
  `GOOGLE_DRIVE` = 2
  `LINK` = 3
  `ONEDRIVE` = 8
  `SMARTSHEET` = 9

## smartsheet.models.enums.automation_action_frequency module

class `smartsheet.models.enums.automation_action_frequency.` `AutomationActionFrequency`(value)

  Bases: `enum.Enum`

  An enumeration.

  `DAILY` = 3
  `HOURLY` = 2
  `IMMEDIATELY` = 1
  `WEEKLY` = 4

## smartsheet.models.enums.automation_action_type module

class `smartsheet.models.enums.automation_action_type.` `AutomationActionType`(value)

  Bases: `enum.Enum`

  An enumeration.

  `APPROVAL_REQUEST_ACTION` = 3
  `NOTIFICATION_ACTION` = 1
  `UPDATE_REQUEST_ACTION` = 2

## smartsheet.models.enums.automation_rule_disabled_reason module

class `smartsheet.models.enums.automation_rule_disabled_reason.` `AutomationRuleDisabledReason`(value)

  Bases: `enum.Enum`

  An enumeration.

  `APPROVAL_COLUMN_MISSING` = 6
  `APPROVAL_COLUMN_WRONG_TYPE` = 7
  `AUTOMATION_NOT_ENABLED_FOR_ORG` = 1
  `COLUMN_MISSING` = 2
  `COLUMN_TYPE_INCOMPATIBLE` = 3
  `NO_POTENTIAL_RECIPIENTS` = 4
  `NO_VALID_SELECTED_COLUMNS` = 5

## smartsheet.models.enums.cell_link_status module

class `smartsheet.models.enums.cell_link_status.` `CellLinkStatus`(value)

  Bases: `enum.Enum`

  An enumeration.

  `BLOCKED` = 5
  `BROKEN` = 2
  `CIRCULAR` = 6
  `DISABLED` = 8
  `INACCESSIBLE` = 3
  `INVALID` = 7
  `NOT_SHARED` = 4
  `OK` = 1

## smartsheet.models.enums.column_type module

class `smartsheet.models.enums.column_type.` `ColumnType`(value)

  Bases: `enum.Enum`

  An enumeration.

  `ABSTRACT_DATETIME` = 9
  `CHECKBOX` = 5
  `CONTACT_LIST` = 4
  `DATE` = 2
  `DATETIME` = 3
  `DURATION` = 7
  `MULTI_CONTACT_LIST` = 10
  `MULTI_PICKLIST` = 11
  `PICKLIST` = 6
  `PREDECESSOR` = 8
  `TEXT_NUMBER` = 1

## smartsheet.models.enums.criteria_target module

class `smartsheet.models.enums.criteria_target.` `CriteriaTarget`(value)

  Bases: `enum.Enum`

  An enumeration.

  `ROW` = 1

## smartsheet.models.enums.cross_sheet_reference_status module

class `smartsheet.models.enums.cross_sheet_reference_status.` `CrossSheetReferenceStatus`(value)

  Bases: `enum.Enum`

  An enumeration.

  `BLOCKED` = 1
  `BROKEN` = 2
  `CIRCULAR` = 3
  `DISABLED` = 4
  `INACCESSIBLE` = 5
  `INVALID` = 6
  `NOT_SHARED` = 7
  `OK` = 8

## smartsheet.models.enums.currency_code module

class `smartsheet.models.enums.currency_code.` `CurrencyCode`(value)

  Bases: `enum.Enum`

  An enumeration.

  `ARS` = 1
  `AUD` = 2
  `BRL` = 3
  `CAD` = 4
  `CHF` = 15
  `CLP` = 5
  `DKK` = 17
  `EUR` = 6
  `GBP` = 7
  `HKD` = 18
  `ILS` = 8
  `INR` = 9
  `JPY` = 10
  `KRW` = 19
  `MXN` = 11
  `NOK` = 20
  `NY` = 16
  `NZD` = 21
  `RUB` = 12
  `SEK` = 22
  `SGD` = 23
  `USD` = 13
  `ZAR` = 14

## smartsheet.models.enums.day_descriptors module

class `smartsheet.models.enums.day_descriptors.` `DayDescriptors`(value)

  Bases: `enum.Enum`

  An enumeration.

  `DAY` = 1
  `FRIDAY` = 9
  `MONDAY` = 5
  `SATURDAY` = 10
  `SUNDAY` = 4
  `THURSDAY` = 8
  `TUESDAY` = 6
  `WEDNESDAY` = 7
  `WEEKDAY` = 2
  `WEEKEND` = 3

## smartsheet.models.enums.day_ordinal module

class `smartsheet.models.enums.day_ordinal.` `DayOrdinal`(value)

  Bases: `enum.Enum`

  An enumeration.

  `FIRST` = 1
  `FOURTH` = 4
  `LAST` = 5
  `SECOND` = 2
  `THIRD` = 3

## smartsheet.models.enums.event_action module

class `smartsheet.models.enums.event_action.` `EventAction`(value)

  Bases: `enum.Enum`

  An enumeration.

  `ACCEPT_INVITE` = 50
  `ACTIVATE` = 8
  `ADD_MEMBER` = 24
  `ADD_PUBLISH` = 16
  `ADD_SHARE` = 18
  `ADD_SHARE_MEMBER` = 20
  `ADD_TO_ACCOUNT` = 53
  `ADD_WORKSPACE_SHARE` = 22
  `AUTHORIZE` = 54
  `BULK_UPDATE` = 37
  `COPY_ROW` = 13
  `CREATE` = 1
  `CREATE_CELL_LINK` = 27
  `CREATE_RECURRING_BACKUP` = 40
  `DEACTIVATE` = 9
  `DECLINE_INVITE` = 49
  `DELETE` = 4
  `DELETE_RECURRING_BACKUP` = 42
  `DOWNLOAD_LOGIN_HISTORY` = 33
  `DOWNLOAD_PUBLISHED_ITEMS_REPORT` = 34
  `DOWNLOAD_SHEET_ACCESS_REPORT` = 31
  `DOWNLOAD_USER_LIST` = 32
  `EXPORT` = 10
  `IMPORT_USERS` = 36
  `LIST_SHEETS` = 38
  `LOAD` = 3
  `MOVE` = 11
  `MOVE_ROW` = 12
  `PURGE` = 5
  `REMOVE_FROM_ACCOUNT` = 52
  `REMOVE_FROM_GROUPS` = 43
  `REMOVE_MEMBER` = 25
  `REMOVE_PUBLISH` = 17
  `REMOVE_SHARE` = 19
  `REMOVE_SHARES` = 28
  `REMOVE_SHARE_MEMBER` = 21
  `REMOVE_WORKSPACE_SHARE` = 23
  `RENAME` = 7
  `REQUEST_BACKUP` = 39
  `RESTORE` = 6
  `REVOKE` = 55
  `SAVE_AS_NEW` = 14
  `SAVE_AS_TEMPLATE` = 15
  `SEND` = 46
  `SEND_AS_ATTACHMENT` = 44
  `SEND_COMMENT` = 47
  `SEND_INVITE` = 48
  `SEND_PASSWORD_RESET` = 51
  `SEND_ROW` = 45
  `TRANSFER_OWNED_GROUPS` = 29
  `TRANSFER_OWNED_ITEMS` = 30
  `TRANSFER_OWNERSHIP` = 26
  `UPDATE` = 2
  `UPDATE_MAIN_CONTACT` = 35
  `UPDATE_RECURRING_BACKUP` = 41

## smartsheet.models.enums.event_obejct_type module

class `smartsheet.models.enums.event_obejct_type.` `EventObjectType`(value)

  Bases: `enum.Enum`

  An enumeration.

  `ACCESS_TOKEN` = 1
  `ACCOUNT` = 2
  `ATTACHMENT` = 3
  `DASHBOARD` = 4
  `DISCUSSION` = 5
  `FOLDER` = 6
  `FORM` = 7
  `GROUP` = 8
  `REPORT` = 10
  `SHEET` = 9
  `UPDATE_REQUEST` = 11
  `USER` = 12
  `WORKSPACE` = 13

## smartsheet.models.enums.event_source module

class `smartsheet.models.enums.event_source.` `EventSource`(value)

  Bases: `enum.Enum`

  An enumeration.

  `API_INTEGRATED_APP` = 4
  `API_UNDEFINED_APP` = 5
  `MOBILE_ANDROID` = 3
  `MOBILE_IOS` = 2
  `UNKNOWN` = 6
  `WEB_APP` = 1

## smartsheet.models.enums.global_template module

class `smartsheet.models.enums.global_template.` `GlobalTemplate`(value)

  Bases: `enum.Enum`

  An enumeration.

  `BLANK_SHEET` = 1
  `PROJECT_SHEET` = 3
  `TASK_LIST` = 2

## smartsheet.models.enums.operator module

class `smartsheet.models.enums.operator.` `Operator`(value)

  Bases: `enum.Enum`

  An enumeration.

  `BETWEEN` = 9
  `CONTAINS` = 7
  `DOES_NOT_CONTAIN` = 8
  `EQUAL` = 1
  `FUTURE` = 15
  `GREATER_THAN` = 3
  `GREATER_THAN_OR_EQUAL` = 4
  `HAS_ALL_OF` = 41
  `HAS_ANY_OF` = 39
  `HAS_ATTACHMENTS` = 35
  `HAS_COMMENTS` = 37
  `HAS_NONE_OF` = 40
  `IS_BLANK` = 21
  `IS_CHECKED` = 27
  `IS_CURRENT_USER` = 31
  `IS_DATE` = 25
  `IS_NOT_BLANK` = 22
  `IS_NOT_CHECKED` = 28
  `IS_NOT_CURRENT_USER` = 32
  `IS_NOT_DATE` = 26
  `IS_NOT_NUMBER` = 24
  `IS_NOT_ONE_OF` = 30
  `IS_NUMBER` = 23
  `IS_ONE_OF` = 29
  `LAST_N_DAYS` = 17
  `LESS_THAN` = 5
  `LESS_THAN_OR_EQUAL` = 6
  `NEXT_N_DAYS` = 19
  `NOT_ALL_OF` = 42
  `NOT_BETWEEN` = 10
  `NOT_EQUAL` = 2
  `NOT_FUTURE` = 16
  `NOT_LAST_N_DAYS` = 18
  `NOT_NEXT_N_DAYS` = 20
  `NOT_ON_CRITICAL_PATH` = 34
  `NOT_PAST` = 14
  `NOT_TODAY` = 12
  `NO_ATTACHMENTS` = 36
  `NO_COMMENTS` = 38
  `ON_CRITICAL_PATH` = 33
  `PAST` = 13
  `TODAY` = 11

## smartsheet.models.enums.paper_type module

class `smartsheet.models.enums.paper_type.` `PaperType`(value)

  Bases: `enum.Enum`

  An enumeration.

  `A0` = 9
  `A1` = 8
  `A2` = 7
  `A3` = 6
  `A4` = 5
  `ARCHD` = 4
  `LEGAL` = 2
  `LETTER` = 1
  `WIDE` = 3

## smartsheet.models.enums.predecessor_type module

class `smartsheet.models.enums.predecessor_type.` `PredecessorType`(value)

  Bases: `enum.Enum`

  An enumeration.

  `FF` = 2
  `FS` = 1
  `SF` = 4
  `SS` = 3

## smartsheet.models.enums.publish_accessible_by module

class `smartsheet.models.enums.publish_accessible_by.` `PublishAccessibleBy`(value)

  Bases: `enum.Enum`

  An enumeration.

  `ALL` = 1
  `ORG` = 2

## smartsheet.models.enums.schedule_type module

class `smartsheet.models.enums.schedule_type.` `ScheduleType`(value)

  Bases: `enum.Enum`

  An enumeration.

  `DAILY` = 2
  `MONTHLY` = 4
  `ONCE` = 1
  `WEEKLY` = 3
  `YEARLY` = 5

## smartsheet.models.enums.share_scope module

class `smartsheet.models.enums.share_scope.` `ShareScope`(value)

  Bases: `enum.Enum`

  An enumeration.

  `ITEM` = 1
  `WORKSPACE` = 2

## smartsheet.models.enums.share_type module

class `smartsheet.models.enums.share_type.` `ShareType`(value)

  Bases: `enum.Enum`

  An enumeration.

  `GROUP` = 2
  `USER` = 1

## smartsheet.models.enums.sheet_email_format module

class `smartsheet.models.enums.sheet_email_format.` `SheetEmailFormat`(value)

  Bases: `enum.Enum`

  An enumeration.

  `EXCEL` = 3
  `PDF` = 1
  `PDF_GANTT` = 2

## smartsheet.models.enums.sheet_filter_operator module

class `smartsheet.models.enums.sheet_filter_operator.` `SheetFilterOperator`(value)

  Bases: `enum.Enum`

  An enumeration.

  `AND` = 1
  `OR` = 2

## smartsheet.models.enums.sheet_filter_type module

class `smartsheet.models.enums.sheet_filter_type.` `SheetFilterType`(value)

  Bases: `enum.Enum`

  An enumeration.

  `ADHOC` = 1
  `PERSONAL` = 2
  `SHARED` = 3

## smartsheet.models.enums.sort_direction module

class `smartsheet.models.enums.sort_direction.` `SortDirection`(value)

  Bases: `enum.Enum`

  An enumeration.

  `ASCENDING` = 1
  `DESCENDING` = 2

## smartsheet.models.enums.symbol module

class `smartsheet.models.enums.symbol.` `Symbol`(value)

  Bases: `enum.Enum`

  An enumeration.

  `ARROWS_3_WAY` = 14
  `ARROWS_4_WAY` = 15
  `ARROWS_5_WAY` = 16
  `DECISION_SHAPES` = 8
  `DECISION_SYMBOLS` = 7
  `DIRECTIONS_3_WAY` = 17
  `DIRECTIONS_4_WAY` = 18
  `EFFORT` = 24
  `FLAG` = 2
  `HARVEY_BALLS` = 3
  `HEARTS` = 22
  `MONEY` = 23
  `PAIN` = 15
  `PRIORITY` = 4
  `PRIORITY_HML` = 6
  `PROGRESS` = 13
  `RYG` = 5
  `RYGB` = 10
  `RYGG` = 11
  `SIGNAL` = 20
  `SKI` = 19
  `STAR` = 1
  `STAR_RATING` = 21
  `VCR` = 9
  `WEATHER` = 12

## smartsheet.models.enums.system_column_type module

class `smartsheet.models.enums.system_column_type.` `SystemColumnType`(value)

  Bases: `enum.Enum`

  An enumeration.

  `AUTO_NUMBER` = 1
  `CREATED_BY` = 5
  `CREATED_DATE` = 4
  `MODIFIED_BY` = 3
  `MODIFIED_DATE` = 2

## smartsheet.models.enums.update_request_status module

class `smartsheet.models.enums.update_request_status.` `UpdateRequestStatus`(value)

  Bases: `enum.Enum`

  An enumeration.

  `CANCELED` = 3
  `COMPLETE` = 2
  `PENDING` = 1

## smartsheet.models.enums.user_status module

class `smartsheet.models.enums.user_status.` `UserStatus`(value)

  Bases: `enum.Enum`

  An enumeration.

  `ACTIVE` = 1
  `DECLINED` = 3
  `PENDING` = 2

## smartsheet.models.enums.widget_type module

class `smartsheet.models.enums.widget_type.` `WidgetType`(value)

  Bases: `enum.Enum`

  An enumeration.

  `CHART` = 1
  `GRIDGANTT` = 4
  `IMAGE` = 2
  `METRIC` = 3
  `RICHTEXT` = 5
  `SHEETSUMMARY` = 11
  `SHORTCUT` = 6
  `SHORTCUTICON` = 10
  `SHORTCUTLIST` = 9
  `TITLE` = 7
  `WEBCONTENT` = 8

## Module contents